#!/bin/sh
#
# Install script for Powerware NetWatch Agent Software
#
# Copyright (c) 1999-2004, by Powerware (R) Corporation. All rights reserved.
:
SHELLTYPE="bourne"
VER="4108"
INSTALL_PATH="/usr/Powerware"
INSTALL_SUBPATH="NetWatch"
INSTALL_TITLE="Powerware NetWatch Installation"
INSTALL_NAME="Powerware NetWatch"
CLIENT="client"
CLIENTDEP="netwatch"
CLIENTEXE="netwatch"
SHUTDOWN="client"
system=""
SCRIPTDIR="scripts"
TEMPDIR="temp"
TARHEADER="NetWatch_"
TARTRAILER="_unix"
TARNAME=""
PATH=$PATH:/bin:/usr/bin:/usr/sbin:/etc:/usr/ucb:.; export PATH
LINK0=""
LINK1=""
LINK2=""
LINK3=""
LINK4=""
LINK5=""
LINK6=""
INITFILE=""
INITTAB="no"
INITTABNAME=$CLIENTEXE
system=""
already_installed=""
make_call=""
debug_call=""
os_type=""
as_type="inittab_autostart"
OLD_INSTALL_PATH="/etc/powerware"
OLD_INSTALL_SUBPATH="netwatch"

compute_system () {
    set `uname -a`
    case $1 in
        AIX)
            os_type="AIX (RS6000)"
            as_type="inittab_autostart"
            INITTAB="yes"
            case $4 in
            3)
                system="aix3"
                make_call="aix"
                ;;
            4)
                system="aix4"
                make_call="aix"
                ;;
            5)
                system="aix5"
                make_call="aix"
                ;;
            esac
            ;;
        FreeBSD)
            os_type="FreeBSD"
            as_type="bsd_autostart"
            system="freebsd"
            make_call="freebsd"
            ;;
        HP-UX)
            if [ -d /sbin/init.d ]; then
                as_type="sbin_autostart"
            fi
            case $5 in
                */7*)
                    os_type="HP-UX (S700)"
                    system="hpux"
                    make_call="hpux"
                    case $3 in
                    *11*)
                        os_type="HP-UX 11 (S700)"
                        system="hpux"
                        ;;
                    esac
                    ;;
                */8*)
                    os_type="HP-UX (S800)"
                    system="hpux"
                    make_call="hpux"
                    case $3 in
                    *11*)
                        os_type="HP-UX 11 (S800)"
                        system="hpux"
                        ;;
                    esac
                    ;;
            esac
            ;;
        IRIX|IRIX64)
            os_type="IRIX (SGI)"
            as_type="etc_autostart"
            if [ -d /sbin/init.d ]; then
                as_type="sbin_autostart"
            fi
            system="irix"
            make_call="irix"
            ;;
        Linux)
            set `uname -m`
            case $1 in
                *86)
                    os_type="LINUX (x86)"
                    as_type="etc_autostart"
                    system="linux_i386"
                    make_call="linux"
                    ;;
                ia64)
                    os_type="LINUX (x86)"
                    as_type="etc_autostart"
                    system="linux_i386"
                    make_call="linux"
                    ;;
                alpha)
                    os_type="LINUX (Alpha)"
                    as_type="etc_autostart"
                    system="linux_axp"
                    make_call="linux"
                    ;;
            esac
            ;;
        OSF1)
            os_type="Compaq TRU64"
            if [ -d /sbin/init.d ]; then
                as_type="sbin_autostart"
            fi
            system="tru64"
            make_call="tru64"
            ;;
        SCO_SV)
            os_type="SCO UNIX"
            if [ -d /etc/init.d ]; then
                as_type="etc_autostart"
            fi
            system="sco"
            make_call="sco"
            ;;
        SunOS)
            if [ -d /etc/init.d ]; then
                as_type="etc_autostart"
            fi
            case $3 in
            5.*)
                case $5 in
                    i86pc)
                        os_type="Solaris (x86)"
                        system="solaris_x86"
                        make_call="solaris_x86"
                        ;;
                    *)
                        os_type="Solaris (SPARC)"
                        system="solaris"
                        make_call="solaris"
                        ;;
                esac
            ;;
            *)
                os_type="SunOS"
                system="sunos"
                make_call="sunos"
                ;;
            esac
            ;;
        UnixWare)
            os_type="SCO UNIXWARE 7"
            if [ -d /etc/init.d ]; then
                as_type="etc_autostart"
            fi
            system="uw7"
            make_call="uw"
            ;;
        UNIX_SV)
            if [ -d /etc/init.d ]; then
                as_type="etc_autostart"
            fi
            if [ -f /etc/issue ]; then
                grep "UnixWare" /etc/issue >/dev/null 2>/dev/null
                if [ $? != 1 ]; then
                    case $4 in
                        2.*)
                            os_type="SCO UNIXWARE 2"
                            system="uw2"
                            make_call="uw"
                        ;;
                        7.*)
                            os_type="SCO UNIXWARE 7"
                            system="uw7"
                            make_call="uw"
                        ;;
                    esac
                else
                    os_type="AT&T UNIX"
                    as_type="etc_autostart"
                    system="svr4"
                    make_call="svr4"
                fi
            else
                os_type="AT&T UNIX"
                as_type="etc_autostart"
                system="svr4"
                make_call="svr4"
            fi
            ;;
        *)
            if [ -c /dev/tty1A ]; then
                os_type="SCO UNIX"
                if [ -d /etc/init.d ]; then
                    as_type="etc_autostart"
                fi
                system="sco"
                make_call="sco"
            else
                os_type="AT&T UNIX"
                as_type="etc_autostart"
                system="svr4"
                make_call="svr4"
            fi
            ;;
    esac
}

findproc() {
    set `uname -a`
    case $1 in
        Darwin)
            pids=`ps -ax | egrep $CLIENTEXE | egrep -v 'egrep' | awk '{print $1}'`
            ;;
        FreeBSD)
            pids=`ps -ax | egrep $CLIENTEXE | egrep -v 'egrep' | awk '{print $1}'`
            ;;
        HP-UX)
            pids=`ps -e | egrep $CLIENTEXE | egrep -v 'egrep' | awk '{print $1}'`
            ;;
        *)
            pids=`ps -o pid,comm -A | egrep $CLIENTEXE | egrep -v 'egrep' | awk '{print $1}'`
            ;;
    esac
}

check_installed () {
    already_installed=""

    pids=""
    findproc
    if [ -n "$pids" ]; then
        already_installed="yes"
    fi

    if [ -d $INSTALL_PATH/$INSTALL_SUBPATH ]; then
        already_installed="yes"
    fi

    if [ -d $OLD_INSTALL_PATH/$OLD_INSTALL_SUBPATH ]; then
        already_installed="yes"
    fi

    if [ "$as_type" = etc_autostart -o "$as_type" = sbin_autostart ]; then
        if [ "$as_type" = sbin_autostart ]; then
            if [ -f /sbin/init.d/$CLIENTDEP.init ]; then
                already_installed="yes"
            fi
        else
            if [ "$make_call" = linux ]; then
                if [ -f /etc/rc.d/init.d/$CLIENTDEP.init ]; then
                    already_installed="yes"
                fi
            else
                if [ -f /etc/init.d/$CLIENTDEP.init ]; then
                    already_installed="yes"
                fi
            fi
        fi
    fi
}

kill_old_client() {
    pidargs="-elo pid,comm"     # sunos
    ps $pidargs > /dev/null 2>&1
    if [ $? != "0" ]; then
        pidargs=-ax
        ps -ax > /dev/null 2>&1
        if [ $? != "0" ]; then
            pidargs=-e  # svr3 svr4
        fi
    fi

    #HP-UX 11.11 does not use -ax
    set `uname -a`
    case $1 in
        HP-UX)
            pidargs=-e
            ;;
        *)
            ;;
    esac
    pids=`ps $pidargs | egrep $CLIENTEXE | egrep -v 'egrep' | awk '{ print $1 }'`
    nohup kill -9 $pids > /dev/null 2>&1
}

remove_old_links() {
    if [ "$as_type" = etc_autostart -o "$as_type" = sbin_autostart ]; then
        #SYSV style
        if [ "$make_call" = linux ]; then
            OLDLINK0=/etc/rc.d/rc0.d/K99$CLIENTDEP.init
            OLDLINK1=/etc/rc.d/rc1.d/K99$CLIENTDEP.init
            OLDLINK2=/etc/rc.d/rc2.d/S99$CLIENTDEP.init
            OLDLINK3=/etc/rc.d/rc3.d/S99$CLIENTDEP.init
            OLDLINK4=/etc/rc.d/rc4.d/S99$CLIENTDEP.init
            OLDLINK5=/etc/rc.d/rc5.d/S99$CLIENTDEP.init
            OLDLINK6=/etc/rc.d/rc6.d/S99$CLIENTDEP.init
            for i in 0 1 2 3 4 5 6
            do
                eval thisname=\$OLDLINK$i
                if [ -h "$thisname" ]; then
                    rm -f $thisname
                fi
            done

            if [ -d /sbin/init.d ]; then
                # SuSe?
                OLDINITFILE=/sbin/init.d/$CLIENTDEP.init
                OLDLINK0=/sbin/init.d/rc0.d/K89$CLIENTDEP.init
                OLDLINK3=/sbin/init.d/rc3.d/S89$CLIENTDEP.init
                return
            elif [ -d /etc/rc.d/init.d ]; then
                # Most Linuxes?
                OLDINITFILE=/etc/rc.d/init.d/$CLIENTDEP.init
                OLDLINK0=/etc/rc.d/rc0.d/K89$CLIENTDEP.init
                OLDLINK3=/etc/rc.d/rc3.d/S89$CLIENTDEP.init
                OLDLINK5=/etc/rc.d/rc5.d/S89$CLIENTDEP.init
                return
            elif [ -d /etc/init.d ]; then
                # SuSe 7.2 or 8.0
                OLDINITFILE=/etc/init.d/$CLIENTDEP.init
                OLDLINK0=/etc/init.d/rc0.d/K89$CLIENTDEP.init
                OLDLINK5=/etc/init.d/rc5.d/S89$CLIENTDEP.init
                return
            else
                # Other cases?
                OLDINITFILE=/sbin/init.d/$CLIENTDEP.init
                OLDLINK1=/sbin/rc1.d/K485$CLIENTDEP.init
                OLDLINK2=/sbin/rc2.d/S515$CLIENTDEP.init
                OLDLINK3=/sbin/rc1.d/K99$CLIENTDEP.init
                OLDLINK4=/sbin/rc2.d/S99$CLIENTDEP.init
                OLDLINK5=/sbin/rc2.d/S89$CLIENTDEP.init
            fi
        else
            if [ "$as_type" = sbin_autostart ]; then
                OLDINITFILE=/sbin/init.d/$CLIENTDEP.init
                if [ "$system" = tru64 ]; then
                    OLDLINK0=/sbin/rc3.d/K99$CLIENTDEP.init
                    OLDLINK3=/sbin/rc3.d/S99$CLIENTDEP.init
                    OLDLINK4=/sbin/rc3.d/S89$CLIENTDEP.init
                else
                    OLDLINK1=/sbin/rc1.d/K99$CLIENTDEP.init
                    OLDLINK2=/sbin/rc2.d/S99$CLIENTDEP.init
                    OLDLINK3=/sbin/rc2.d/S89$CLIENTDEP.init
                fi
            else
                OLDINITFILE=/etc/init.d/$CLIENTDEP.init
                OLDLINK0=/etc/rc0.d/K99$CLIENTDEP.init
                OLDLINK2=/etc/rc2.d/S99$CLIENTDEP.init
                OLDLINK3=/etc/rc2.d/S89$CLIENTDEP.init
            fi
        fi

        if [ -f $OLDINITFILE ]; then
            rm -f $OLDINITFILE
        fi

        for i in 0 1 2 3 4 5 6
        do
            eval thisname=\$OLDLINK$i
            if [ -h "$thisname" ]; then
                rm -f $thisname
            fi
        done
    elif [ "$as_type" = bsd_autostart ]; then
        #BSD style
        OLDINITFILE=/usr/local/etc/rc.d/$CLIENTDEP.sh
        if [ -f "$thisname" ]; then
            rm -f $OLDINITFILE
        fi
    else
        oldinittabfile=/etc/inittab
        # Backup old inittab
        mv -f $oldinittabfile ${oldinittabfile}.tmp
        check_fatal
        sed -e '
/^'$INITTABNAME':234:once:/d
' ${oldinittabfile}.tmp > $oldinittabfile
        check_fatal
        # Fixup perms on inittab.
        chmod 755 $oldinittabfile
        check_fatal
    fi
}

remove_old_client() {
    if [ -d $instpath ]; then
        rm -f $instpath/*
        rm -r $instpath
    fi
    oldinstpath=$OLD_INSTALL_PATH/$OLD_INSTALL_SUBPATH
    if [ -d $oldinstpath ]; then
        rm -f $oldinstpath/*
        rm -r $oldinstpath
    fi
    if [ -d $OLD_INSTALL_PATH ]; then
        rm -r $OLD_INSTALL_PATH
    fi
}

echo_n () {
    echo "$*"
}

read_def () {
    prompt=$1
    default=$2

    echo_n "$prompt"
    read answer
    if [ -z "$answer" ]; then
        answer=$default
    fi
}

create_path() {
    fullpath=""
    for path in `echo $1 | sed 's/\// /g'`; do
        fullpath=$fullpath/$path
        if [ ! -d $fullpath ]; then
            mkdir $fullpath
            if [ $? != 0 ]; then
                return 1
            fi
            if [ "$system" = svr4 ]; then
                chown -R 0 $fullpath
                chmod -R 755 $fullpath
            else
                chown -R 0:0 $fullpath
                chmod 755 $fullpath
                chown bin $fullpath
                chgrp bin $fullpath
            fi
            if [ $? != 0 ]; then
                return 1
            fi
        fi
    done
    if [ -d $1 ]; then
        return 0
    fi
    return 1
}

fixup_linux_system () {
    stty ocrnl onocr onlret echonl inlcr echok echoe erase 

    if [ -d /usr/lib/terminfo ]; then
        ln -s /usr/lib/terminfo /usr/share/terminfo
    elif [ -d /usr/share/terminfo ]; then
        ln -s /usr/share/terminfo /usr/lib/terminfo
    else
        echo "No terminfo files in either /usr/share/ or /usr/lib/"
    fi
}

check_fatal () {
    if [ $? != 0 ]; then
        if [ $override ]; then
            echo "Install failed. Override set."
            return 0
        fi
        echo "Install failed. Exiting"
        exit 1
    fi
}

bsd_startatboot () {

    # Create the startup script file and save location for unistall
    INITFILE=/usr/local/etc/rc.d/$CLIENTDEP.sh

    cp   $instpath/header.$SHELLTYPE                            /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "case \"\$1\" in"                                   >> /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "    start)"                                        >> /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "        if [ -x $instpath/$CLIENTDEP.init ]; then" >> /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "            $instpath/$CLIENTDEP.init start"       >> /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "        fi"                                        >> /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "    ;;"                                            >> /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "    stop)"                                         >> /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "        $instpath/$CLIENTDEP.init stop"            >> /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "    ;;"                                            >> /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "esac"                                              >> /usr/local/etc/rc.d/$CLIENTDEP.sh
    echo "exit 0"                                            >> /usr/local/etc/rc.d/$CLIENTDEP.sh

    # Fixup perms on startup script.
    chmod 755 /usr/local/etc/rc.d/$CLIENTDEP.sh
    check_fatal
}

sysv_startatboot_linux () {
    if [ -d /sbin/init.d ]; then
        # SuSe?
        INITFILE=/sbin/init.d/$CLIENTDEP.init
        LINK0=/sbin/init.d/rc0.d/K89$CLIENTDEP.init
        LINK3=/sbin/init.d/rc3.d/S89$CLIENTDEP.init
        return
    fi

    if [ -d /etc/rc.d/init.d ]; then
        # Most Linuxes?
        INITFILE=/etc/rc.d/init.d/$CLIENTDEP.init
        LINK0=/etc/rc.d/rc0.d/K89$CLIENTDEP.init
        LINK3=/etc/rc.d/rc3.d/S89$CLIENTDEP.init
        LINK5=/etc/rc.d/rc5.d/S89$CLIENTDEP.init
        return
    fi

    if [ -d /etc/init.d ]; then
        # SuSe 7.2 or 8.0
        INITFILE=/etc/init.d/$CLIENTDEP.init
        LINK0=/etc/init.d/rc0.d/K89$CLIENTDEP.init
        LINK5=/etc/init.d/rc5.d/S89$CLIENTDEP.init
        return
    fi

    # Other cases?
    INITFILE=/sbin/init.d/$CLIENTDEP.init
    LINK1=/sbin/rc1.d/K485$CLIENTDEP.init
    LINK2=/sbin/rc2.d/S515$CLIENTDEP.init
}

sysv_startatboot_other () {
    if [ "$as_type" = sbin_autostart ]; then
        INITFILE=/sbin/init.d/$CLIENTDEP.init
        if [ "$system" = tru64 ]; then
            LINK0=/sbin/rc3.d/K99$CLIENTDEP.init
            LINK3=/sbin/rc3.d/S89$CLIENTDEP.init
        else
            LINK1=/sbin/rc1.d/K485$CLIENTDEP.init
            LINK2=/sbin/rc2.d/S515$CLIENTDEP.init
        fi
    else
        INITFILE=/etc/init.d/$CLIENTDEP.init
        LINK0=/etc/rc0.d/K99$CLIENTDEP.init
        LINK2=/etc/rc2.d/S89$CLIENTDEP.init
    fi
}

sysv_startatboot () {
    if [ "$make_call" = linux ]; then
        sysv_startatboot_linux
    else
        sysv_startatboot_other
    fi

    # Link init file in rc dirs.
    cp $instpath/$CLIENTDEP.init $INITFILE

    echo "Linking $INITFILE to to RC directories... "

    for i in 0 1 2 3 4 5 6
    do
        eval thisname=\$LINK$i
        if [ -n "$thisname" ]; then
            ln -fs $INITFILE $thisname
        fi
    done
}

inittab_startatboot () {
    inittabfile=/etc/inittab
    # Backup old inittab
    mv -f $inittabfile ${inittabfile}.$CLIENTDEP
    check_fatal

    if [ $startatboot = "yes" ]; then
        sed -e '
$a\
'$INITTABNAME':234:once:'$instpath'/'$CLIENTDEP'.init start
/^'$INITTABNAME':234:once:/d
' ${inittabfile}.$CLIENTDEP > $inittabfile
        check_fatal
    else
        sed -e '
/^'$INITTABNAME':234:once:/d
' ${inittabfile}.$CLIENTDEP > $inittabfile
        check_fatal
    fi

    # Fixup perms on inittab.
    chmod 755 $inittabfile
    check_fatal

    # Report differences
    echo "The following lines were removed from $inittabfile:"
    diff ${inittabfile}.$CLIENTDEP $inittabfile | grep '^<' | sed -e 's/< //'
    echo "The following lines were added to $inittabfile:"
    diff ${inittabfile}.$CLIENTDEP $inittabfile | grep '^>' | sed -e 's/> //'
}

main () {
   override=true
    ret=TRUE;
    currentpath=`pwd`
    check_installed

# Set install path
    instpath=$INSTALL_PATH/$INSTALL_SUBPATH

    if [ "$make_call" = linux ]; then
        fixup_linux_system
    fi

# Say hello
    clear
    if [ "$already_installed" = yes ];then
        echo
        echo "---------------------------------------------------------------"
        echo "    Welcome to $INSTALL_TITLE"
        echo "        Version $VER for $os_type"
        echo
        echo "    To install $INSTALL_NAME, select (Y)es"
        echo "    and fill in the configuration items as they"
        echo "    presented to you."
        echo
        echo "    WARNING! $INSTALL_NAME is already installed."
        echo "    If you do not wish to re-install it, select (N)o"
        echo "    to stop the $INSTALL_NAME installation."
        echo "---------------------------------------------------------------"
    else
        echo
        echo "---------------------------------------------------------------"
        echo "    Welcome to $INSTALL_TITLE"
        echo "        Version $VER for $os_type"
        echo
        echo "    To install $INSTALL_NAME, press <ENTER>"
        echo "    and fill in the configuration items as they"
        echo "    presented to you."
        echo "---------------------------------------------------------------"
        echo
    fi
    echo
    read_def "    Continue installation? (y/n) [y] " "y"
    case $answer in
        [yY]|[yY][eE][sS])
            ;;
        *)
            echo
            echo "    Exiting $INSTALL_NAME installation."
            echo
            exit 0
            ;;
    esac

    if [ "$system" = "" ];then
        echo
        echo "    Unable to determine your system."
        echo "    Please enter one of the OS types listed below."
        echo "    or press <ENTER> to exit installation"
        echo
        echo "        aix4   sco     linux_i386"
        echo "        aix5   irix    linux_axp"
        echo "        hpux   solaris solaris_x86"
        echo "        svr4           tru64(Compaq)"
        echo
        read_def "    Enter OS type: "
        if [   '(' "$answer" = aix4 ')' -o '(' "$answer" = aix5       ')' -o '(' "$answer" = solaris     ')'\
            -o '(' "$answer" = hpux ')' -o '(' "$answer" = sco        ')' -o '(' "$answer" = solaris_x86 ')'\
            -o '(' "$answer" = irix ')' -o '(' "$answer" = linux_i386 ')' -o '(' "$answer" = svr4        ')'\
            -o '(' "$answer" = tru64 ')' -o '(' "$answer" = linux_axp ')' ];
        then
            echo
            system=$answer
        else
            echo
            echo "    Exiting $INSTALL_NAME installation."
            echo
            exit 0
        fi
    fi  # end-of big "if system aix4 -o system -o tru64.. "

    if [ "$already_installed" = yes ];then
# Kill the Client program so the install will run OK
        echo "---------------------------------------------------------------"
        echo "    Removing old $INSTALL_NAME Installation:"
        echo
        echo "    Stopping $INSTALL_NAME client."
        kill_old_client
# Remove autostart links and link files
        echo "    Removing old $INSTALL_NAME auto start files."
        remove_old_links
# Remove the program files
        echo "    Removing old $INSTALL_NAME files and directory."
        remove_old_client
    else
        remove_old_links
    fi
# Create the installation directory
    create_path $instpath
    if [ ! $? = 0 ]; then
        echo "    Unable to create the installation path $instpath!"
        exit 0
    fi
# Get the tarfile
    if [ ! -d $instpath/$TEMPDIR ]; then
        mkdir $instpath/$TEMPDIR
        if [ "$system" = svr4 ]; then
            chown -R 0 $instpath/$TEMPDIR
            chmod -R 755 $instpath/$TEMPDIR
        else
            chown -R 0:0 $instpath/$TEMPDIR
            chmod 755 $instpath/$TEMPDIR
            chown bin $instpath/$TEMPDIR
            chgrp bin $instpath/$TEMPDIR
        fi
    fi
    if [ -d $instpath/$TEMPDIR ]; then
        if [ -f ./$TARHEADER$VER$TARTRAILER.tar ]; then
            cp ./$TARHEADER$VER$TARTRAILER.tar $instpath/$TEMPDIR/$TARHEADER$VER$TARTRAILER.tar
            TARNAME=$TARHEADER$VER$TARTRAILER.tar
        elif [ -f ./$TARHEADER$VER$TARTRAILER.tar.gz ]; then
            cp ./$TARHEADER$VER$TARTRAILER.tar.gz $instpath/$TEMPDIR/$TARHEADER$VER$TARTRAILER.tar.gz
            TARNAME=$TARHEADER$VER$TARTRAILER.tar.gz
        else
            echo
            echo "$INSTALL_TITLE Error: Could not find the TAR archive file."
            echo
            if [ -d $instpath/$TEMPDIR ]; then
                rm -r $instpath/$TEMPDIR
            fi
            exit 0
        fi

        if [ -f $instpath/$TEMPDIR/$TARHEADER$VER$TARTRAILER.tar.gz ]; then
            if [ -x gunzip ] || [ -x /bin/gunzip ] || [ -x /usr/bin/gunzip ]; then
                GZIP="no"
            elif [ -x gzip ] || [ -x /bin/gzip ] || [ -x /usr/bin/gzip ]; then
                GZIP="yes"
            else
                if [ -d $instpath ]; then
                    rm -r $instpath
                fi
                echo
                echo "$INSTALL_TITLE Error: Could not find the gzip"
                echo "or gunzip utility on your system. Use the"
                echo "$TARHEADER$VER$TARTRAILER.tar file instead"
                echo
                exit 0
            fi
        fi
    else
        echo
        echo "$INSTALL_TITLE Error: Could not create $instpath/$TEMPDIR directory."
        echo
        exit 0
    fi

# Get start at boot flag
    echo "---------------------------------------------------------------"
    echo "    Automatic Startup:"
    echo
    echo "    To automatically run $INSTALL_NAME upon startup"
    echo "    on the computer being installed, enter (y)es,"
    echo "    otherwise enter (n)o."
    echo
    echo "    NOTE: It is strongly recommended that you select Yes"
    echo "    for this option in order to provide full protection"
    echo "    from multiple power outages."
    echo "---------------------------------------------------------------"
    echo
    read_def "    Automatically run $INSTALL_NAME on startup? (y/n) [y] " "y"
    case $answer in
    [yY]|[yY][eE][sS])
        startatboot="yes"
        ;;
    *)
        startatboot="no"
        ;;
    esac

    echo "---------------------------------------------------------------"
    echo "    $INSTALL_NAME Installation Parameters:"
    echo
    echo "    Target directory: $instpath"
    echo "    Install archive file is: $TARNAME"
    echo "    Run $INSTALL_NAME at bootup: $startatboot"
    echo "---------------------------------------------------------------"
    echo
    answer=""
    read_def "    Are these installation parameters acceptable? (y/n) [y] " "y"
    case $answer in
    [yY]|[yY][eE][sS])
        userverified=true
        ;;
    *)
        echo
        echo "    Exiting $INSTALL_NAME installation."
        if [ -d $instpath ]; then
            rm -r $instpath
        fi
        echo
        exit 0
        ;;
    esac

# Expand the tarfile
    echo "---------------------------------------------------------------"
    cd $instpath/$TEMPDIR
    if [ -f ./$TARHEADER$VER$TARTRAILER.tar.gz ]; then
        echo "Uncompressing $TARHEADER$VER$TARTRAILER.tar.gz file..."
        if [ "$GZIP" = yes ]; then
            gzip -d $TARHEADER$VER$TARTRAILER.tar.gz
        else
            gunzip $TARHEADER$VER$TARTRAILER.tar.gz
        fi
    fi
    echo "Uncompressing $TARHEADER$VER$TARTRAILER.tar file..."
    tar xf ./$TARHEADER$VER$TARTRAILER.tar $system $SCRIPTDIR
    sleep 5
    echo
    echo "...Done"
    echo "---------------------------------------------------------------"
    cd ..

# Copy the program files
    echo "---------------------------------------------------------------"
    echo "Installing the $INSTALL_NAME files for $os_type..."
    echo
    cp    $instpath/$TEMPDIR/$system/*    $instpath
    cp    $instpath/$TEMPDIR/$SCRIPTDIR/* $instpath
    if [ "$system" = svr4 ]; then
        chown -R 0 $instpath
        chmod -R 755 $instpath
    else
        chown -R 0:0 $instpath
        chmod -R 755 $instpath
    fi
    rm    -r $instpath/$TEMPDIR

# Create the Init file
    cp   $instpath/header.$SHELLTYPE     $instpath/$CLIENTDEP.init
    cat  $instpath/$CLIENTDEP.init1   >> $instpath/$CLIENTDEP.init
    echo "SHELLTYPE=\"$SHELLTYPE\""   >> $instpath/$CLIENTDEP.init
    echo "INSTALL_PATH=\"$instpath\"" >> $instpath/$CLIENTDEP.init
    cat  $instpath/$CLIENTDEP.init2   >> $instpath/$CLIENTDEP.init
    cat  $instpath/$CLIENT.init       >> $instpath/$CLIENTDEP.init

# Create the Shutdown file
    cp   $instpath/header.$SHELLTYPE     $instpath/shutdown.sh
    cat  $instpath/$SHUTDOWN.shutdown >> $instpath/shutdown.sh

# Create the Message file
    cp   $instpath/header.$SHELLTYPE     $instpath/$CLIENTDEP.msg
    cat  $instpath/$CLIENT.msg        >> $instpath/$CLIENTDEP.msg

# Setup file permissions
    if [ "$system" = svr4 ]; then
        chown -R 0 $instpath
        chmod -R 755 $instpath
    else
        chown -R 0:0 $instpath
        chmod -R 755 $instpath
    fi
    echo "...Done"
    echo "---------------------------------------------------------------"
    cd $currentpath

# Setup auto start on boot
    if [ "$startatboot" = yes ]; then
        echo "---------------------------------------------------------------"
        if [ "$as_type" = etc_autostart -o "$as_type" = sbin_autostart ]; then
            sysv_startatboot
        elif [ "$as_type" = inittab_autostart ]; then
            inittab_startatboot
        elif [ "$as_type" = bsd_autostart ]; then
            bsd_startatboot
        else
            echo
            echo
            echo "-------------------------------------------------------"
            echo "     Unable to determine how to make your system       "
            echo "     automatically load the $INSTALL_NAME              "
            echo "     at boot time.                                     "
            echo "     Consult the manual for your system.               "
            echo "-------------------------------------------------------"
            echo
            echo
            read_def "  Okay? (y) [y] "
        fi
        echo
        echo "...Done"
        echo "---------------------------------------------------------------"
    fi

# Create the Uninstall file
    cp   $instpath/header.$SHELLTYPE         $instpath/uninstal.sh
    cat  $instpath/$CLIENT.unst1          >> $instpath/uninstal.sh
    echo "SHELLTYPE=\"$SHELLTYPE\""       >> $instpath/uninstal.sh
    echo "VER=\"$VER\""                   >> $instpath/uninstal.sh
    echo "INSTALL_TITLE=\"$INSTALL_TITLE\"">>$instpath/uninstal.sh
    echo "INSTALL_NAME=\"$INSTALL_NAME\"" >> $instpath/uninstal.sh
    echo "INSTALL_PATH=\"$INSTALL_PATH\""       >> $instpath/uninstal.sh
    echo "INSTALL_SUBPATH=\"$INSTALL_SUBPATH\"" >> $instpath/uninstal.sh
    echo "INIT_FILE=\"$CLIENTDEP.init\""  >> $instpath/uninstal.sh
    echo "OS_TYPE=\"$os_type\""           >> $instpath/uninstal.sh
    echo "SYS_TYPE=\"$system\""           >> $instpath/uninstal.sh
    echo "LINK0=\"$LINK0\""               >> $instpath/uninstal.sh
    echo "LINK1=\"$LINK1\""               >> $instpath/uninstal.sh
    echo "LINK2=\"$LINK2\""               >> $instpath/uninstal.sh
    echo "LINK3=\"$LINK3\""               >> $instpath/uninstal.sh
    echo "LINK4=\"$LINK4\""               >> $instpath/uninstal.sh
    echo "LINK5=\"$LINK5\""               >> $instpath/uninstal.sh
    echo "LINK6=\"$LINK6\""               >> $instpath/uninstal.sh
    echo "INITFILE=\"$INITFILE\""         >> $instpath/uninstal.sh
    echo "INITTAB=\"$INITTAB\""           >> $instpath/uninstal.sh
    echo "INITTABNAME=\"$INITTABNAME\""   >> $instpath/uninstal.sh
    echo "CLIENTEXE=\"$CLIENTEXE\""       >> $instpath/uninstal.sh
    cat  $instpath/$CLIENT.unst2          >> $instpath/uninstal.sh

# Remove intermediate files
    rm -f $instpath/header.bourne
    rm -f $instpath/header.posix
    rm -f $instpath/$CLIENT.init
    rm -f $instpath/$CLIENT.msg
    rm -f $instpath/$CLIENT.unst1
    rm -f $instpath/$CLIENT.unst2
    rm -f $instpath/$CLIENTDEP.init1
    rm -f $instpath/$CLIENTDEP.init2
    rm -f $instpath/$SHUTDOWN.shutdown

# Start the NetWatch client in interactive mode
    $instpath/$CLIENTDEP -i
    echo "...Done"
    echo "---------------------------------------------------------------"

# Start the Daemon client
    echo "---------------------------------------------------------------"
    $instpath/$CLIENTDEP.init start
    echo "...Done"
    echo "---------------------------------------------------------------"

#  Install complete
    echo
    echo "---------------------------------------------------------------"
    echo "$INSTALL_NAME was successfully"
    echo "installed on your system."
    echo "---------------------------------------------------------------"
    echo
}

##########################################################
#
#       Start of Main Script
#
##########################################################

clear

# Find out what UNIX we're running.
compute_system

# Check for super user
if [ "$system" = solaris ] || [ "$system" = solaris_x86 ]; then
    if [ -x /usr/xpg4/bin/id ]; then
        ID=`/usr/xpg4/bin/id -u`
    else
        echo
        echo "/bin/id doesn't exist:  Unable to check if user is root, exiting..."
        echo
        exit 1
    fi
elif [ "$system" = svr4 ]; then
    if [ -x /bin/id ] || [ -x /usr/bin/id ]; then
        ID=`id -a | awk '{print $1;}' | grep "uid=0"`
    else
        echo
        echo "/bin/id doesn't exist:  Unable to check if user is root, exiting..."
        echo
        exit 1
    fi
else
    if [ -x /bin/id ] || [ -x /usr/bin/id ]; then
        ID=`id -u`
    else
        echo
        echo "/bin/id doesn't exist:  Unable to check if user is root, exiting..."
        echo
        exit 1
    fi
fi

if [ $ID -ne 0 ]; then
  echo
  echo "Sorry, you must be root to perform this operation."
  echo
  exit 1
fi

main $1
